@@ -1,8 +1,7 @@
-import click
+import click, time
 
 from octohot.cli.regex.colored_texts import Colors
 
-
 @click.command()
 @click.argument('pr_title')
 @click.argument('pr_comment')
@@ -33,6 +32,11 @@ def _pr(github_login, repo, pr_title, pr_comment, branch_name, default_branch, o
                 break
             except exceptions.NotFoundError:
                 continue
-
-    pr = github_repo.create_pull(pr_title, origin, branch_name, pr_comment)
-    click.echo(color.success("PR github repo %s PR %s branch %s: %s" % (repo.name, pr_title, branch_name, pr.url)))
+    
+    try:
+        pr = github_repo.create_pull(pr_title, origin, branch_name, pr_comment)
+        click.echo(color.success("PR github repo %s PR %s branch %s: %s" % (repo.name, pr_title, branch_name, pr.html_url)))
+    except Exception as err:
+        click.echo(color.fail("Failed to create PR for repo %s, exception: %s" % (repo.name, err)))
+    finally:
+        time.sleep(2)
